SharedMemIf = [
        {
            'Name' : 'Term1',
            'Type' : 'f',
            'Offset' : 0,
            'Size' : 4
        },
        {
            'Name' : 'Term2',
            'Type' : 'f',
            'Offset' : 4,
            'Size' : 4
        },
        {
            'Name' : 'Term3',
            'Type' : 'f',
            'Offset' : 8,
            'Size' : 4
        },
        {
            'Name' : 'Term4',
            'Type' : 'f',
            'Offset' : 12,
            'Size' : 4
        },
        {
            'Name' : 'Term5',
            'Type' : 'f',
            'Offset' : 16,
            'Size' : 4
        }
    ]

memory_map = 'mem_files/mem_map_file'

